@@ -21,8 +21,6 @@
 
 #include "gtksourcecompletionwordsproposal.h"
 
-#define GTK_SOURCE_COMPLETION_WORDS_PROPOSAL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GTK_SOURCE_TYPE_COMPLETION_WORDS_PROPOSAL, GtkSourceCompletionWordsProposalPrivate))
-
 struct _GtkSourceCompletionWordsProposalPrivate
 {
 	gchar *word;
@@ -42,6 +40,7 @@ static void gtk_source_completion_proposal_iface_init (gpointer g_iface, gpointe
 G_DEFINE_TYPE_WITH_CODE (GtkSourceCompletionWordsProposal,
 			 gtk_source_completion_words_proposal,
 			 G_TYPE_OBJECT,
+			 G_ADD_PRIVATE (GtkSourceCompletionWordsProposal)
 			 G_IMPLEMENT_INTERFACE (GTK_SOURCE_TYPE_COMPLETION_PROPOSAL,
 			 			gtk_source_completion_proposal_iface_init))
 
@@ -90,15 +89,12 @@ gtk_source_completion_words_proposal_class_init (GtkSourceCompletionWordsProposa
 		              g_cclosure_marshal_VOID__VOID,
 		              G_TYPE_NONE,
 		              0);
-
-	g_type_class_add_private (object_class, sizeof(GtkSourceCompletionWordsProposalPrivate));
 }
 
 static void
 gtk_source_completion_words_proposal_init (GtkSourceCompletionWordsProposal *self)
 {
-	self->priv = GTK_SOURCE_COMPLETION_WORDS_PROPOSAL_GET_PRIVATE (self);
-
+	self->priv = gtk_source_completion_words_proposal_get_instance_private (self);
 	self->priv->use_count = 1;
 }
 
